package com.example.caobotao.learnsharedpreferences;

import android.content.SharedPreferences;
import android.preference.PreferenceManager;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {
    //声明控件
    private EditText etUsername, etPassword;
    private TextView tvUsername, tvPassword, tvSaveUsername;
    private CheckBox cbSaveUsername;
    private Button btLogin, btCancel;
    //声明SharedPreferences对象
    private SharedPreferences preferences;
    //声明Editor对象
    private SharedPreferences.Editor editor;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        initViews();//初始化控件
        /**
         *  通过getSharedPreferences方法获取SharedPreferences对象，
         *  getSharedPreferences(String name,int mode)
         *  name: 生成的XML文件的名字
         *  mode: 生成的XML文件的权限(是否能被其他程序读取等)
         *
         *  也可以使用PreferenceManager.getDefaultSharedPreferences(this)获取SharedPreferences对象，
         *  这样生成的XML文件名为: 包名+“_preferences”
         *  XML权限为:MODE_PRIVATE
         */
//        preferences = PreferenceManager.getDefaultSharedPreferences(this);
        preferences = getSharedPreferences("myPref", MODE_PRIVATE);
        //获取Editor对象
        editor = preferences.edit();
        //通过SharedPreferences对象的getXxx方法获取Key对应的Value，第二个参数为默认值
        String name = preferences.getString("username", "");
        //如果name为空，说明还未进行过用户名的存储
        if (name == null) {
            cbSaveUsername.setChecked(false);
        } else {//如果不为空则将已存储的用户名自动填写到编辑框中
            cbSaveUsername.setChecked(true);
            etUsername.setText(name);
        }

    }

    //初始化控件
    private void initViews() {
        etUsername = (EditText) findViewById(R.id.etUsername);
        etPassword = (EditText) findViewById(R.id.etPassword);
        tvUsername = (TextView) findViewById(R.id.tvUsername);
        tvPassword = (TextView) findViewById(R.id.tvPassword);
        tvSaveUsername = (TextView) findViewById(R.id.tvRememberUsername);
        cbSaveUsername = (CheckBox) findViewById(R.id.cbRememberUsername);
        btLogin = (Button) findViewById(R.id.btnLogin);
        btCancel = (Button) findViewById(R.id.btnCancel);
        btLogin.setOnClickListener(this);
        btCancel.setOnClickListener(this);
    }

    //按钮点击事件
    @Override
    public void onClick(View v) {
        //获取到编辑框中的用户名和密码
        String name = etUsername.getText().toString();
        String pass = etPassword.getText().toString();

        switch (v.getId()) {
            //登录按钮的点击处理
            case R.id.btnLogin:
                //如果用户名和密码合法
                if ("admin".equals(name) && "abc123".equals(pass)) {
                    //如果勾选了保存用户名的复选框，则将用户名存储到XML文件中
                    if (cbSaveUsername.isChecked()) {
                        editor.putString("username", name);
                    } else {//如果没有勾选则将用户名从XML文件中移除(如果有的话)
                        editor.remove("username");
                    }
                    //使用Editor对象操作后，需要调用commit方法进行提交，不然所有的操作都无效。类似与数据库中事务的提交
                    editor.commit();
                    Toast.makeText(this, "登录成功", Toast.LENGTH_SHORT).show();
                } else {
                    Toast.makeText(this, "登录失败", Toast.LENGTH_SHORT).show();
                }
                break;
            case R.id.btnCancel:
                break;
        }
    }
}
